@@ -19,8 +19,8 @@ import gdb
 import os
 import os.path
 
-pythondir = '/data/jenkins/workspace/GNU-toolchain/arm-14-2/build-arm-none-eabi/install/share/gcc-14.2.1/python'
-libdir = '/data/jenkins/workspace/GNU-toolchain/arm-14-2/build-arm-none-eabi/install/arm-none-eabi/lib/thumb/v7e-m/nofp'
+pythondir = '/tmp/jenkins-f07d89a2/workspace/GNU-toolchain/arm-14-2/build-arm-none-eabi/install/share/gcc-14.3.1/python'
+libdir = '/tmp/jenkins-f07d89a2/workspace/GNU-toolchain/arm-14-2/build-arm-none-eabi/install/arm-none-eabi/lib/thumb/v7e-m/nofp'
 
 # This file might be loaded when there is no current objfile.  This
 # can happen if the user loads it manually.  In this case we don't
